@@ -16,7 +16,7 @@
 # This R package was created for academic research and was publicly    #
 # released in the hope that it will be useful, but it comes WITHOUT    #
 # ANY WARRANTY OR LIABILITY.                                           #
-# Visit our website for more info: https://msberends.gitab.io/AMR.     #
+# Visit our website for more info: https://msberends.gitlab.io/AMR.    #
 # ==================================================================== #
 
 #' Count isolates
@@ -26,6 +26,7 @@
 #' \code{count_R} and \code{count_IR} can be used to count resistant isolates, \code{count_S} and \code{count_SI} can be used to count susceptible isolates.\cr
 #' @param ... one or more vectors (or columns) with antibiotic interpretations. They will be transformed internally with \code{\link{as.rsi}} if needed.
 #' @inheritParams portion
+#' @inheritSection as.rsi Interpretation of S, I and R
 #' @details These functions are meant to count isolates. Use the \code{\link{portion}_*} functions to calculate microbial resistance.
 #'
 #' \code{n_rsi} is an alias of \code{count_all}. They can be used to count all available isolates, i.e. where all input antibiotics have an available result (S, I or R). Their use is equal to \code{\link{n_distinct}}. Their function is equal to \code{count_S(...) + count_IR(...)}.
@@ -44,55 +45,55 @@
 #' ?septic_patients
 #'
 #' # Count resistant isolates
-#' count_R(septic_patients$amox)
-#' count_IR(septic_patients$amox)
+#' count_R(septic_patients$AMX)
+#' count_IR(septic_patients$AMX)
 #'
 #' # Or susceptible isolates
-#' count_S(septic_patients$amox)
-#' count_SI(septic_patients$amox)
+#' count_S(septic_patients$AMX)
+#' count_SI(septic_patients$AMX)
 #'
 #' # Count all available isolates
-#' count_all(septic_patients$amox)
-#' n_rsi(septic_patients$amox)
+#' count_all(septic_patients$AMX)
+#' n_rsi(septic_patients$AMX)
 #'
 #' # Since n_rsi counts available isolates, you can
 #' # calculate back to count e.g. non-susceptible isolates.
 #' # This results in the same:
-#' count_IR(septic_patients$amox)
-#' portion_IR(septic_patients$amox) * n_rsi(septic_patients$amox)
+#' count_IR(septic_patients$AMX)
+#' portion_IR(septic_patients$AMX) * n_rsi(septic_patients$AMX)
 #'
 #' library(dplyr)
 #' septic_patients %>%
 #'   group_by(hospital_id) %>%
-#'   summarise(R  = count_R(cipr),
-#'             I  = count_I(cipr),
-#'             S  = count_S(cipr),
-#'             n1 = count_all(cipr), # the actual total; sum of all three
-#'             n2 = n_rsi(cipr),     # same - analogous to n_distinct
+#'   summarise(R  = count_R(CIP),
+#'             I  = count_I(CIP),
+#'             S  = count_S(CIP),
+#'             n1 = count_all(CIP),  # the actual total; sum of all three
+#'             n2 = n_rsi(CIP),      # same - analogous to n_distinct
 #'             total = n())          # NOT the number of tested isolates!
 #'
 #' # Count co-resistance between amoxicillin/clav acid and gentamicin,
 #' # so we can see that combination therapy does a lot more than mono therapy.
 #' # Please mind that `portion_S` calculates percentages right away instead.
-#' count_S(septic_patients$amcl)   # S = 1057 (67.1%)
-#' count_all(septic_patients$amcl) # n = 1576
+#' count_S(septic_patients$AMC)   # S = 1342 (71.4%)
+#' count_all(septic_patients$AMC) # n = 1879
 #'
-#' count_S(septic_patients$gent)   # S = 1372 (74.0%)
-#' count_all(septic_patients$gent) # n = 1855
+#' count_S(septic_patients$GEN)   # S = 1372 (74.0%)
+#' count_all(septic_patients$GEN) # n = 1855
 #'
 #' with(septic_patients,
-#'      count_S(amcl, gent))       # S = 1396 (92.0%)
-#' with(septic_patients,           # n = 1517
-#'      n_rsi(amcl, gent))
+#'      count_S(AMC, GEN))         # S = 1660 (92.3%)
+#' with(septic_patients,           # n = 1798
+#'      n_rsi(AMC, GEN))
 #'
 #' # Get portions S/I/R immediately of all rsi columns
 #' septic_patients %>%
-#'   select(amox, cipr) %>%
+#'   select(AMX, CIP) %>%
 #'   count_df(translate = FALSE)
 #'
 #' # It also supports grouping variables
 #' septic_patients %>%
-#'   select(hospital_id, amox, cipr) %>%
+#'   select(hospital_id, AMX, CIP) %>%
 #'   group_by(hospital_id) %>%
 #'   count_df(translate = FALSE)
 #'
@@ -172,66 +173,16 @@ n_rsi <- function(...) {
 #' @importFrom dplyr %>% select_if bind_rows summarise_if mutate group_vars select everything
 #' @export
 count_df <- function(data,
-                     translate_ab = getOption("get_antibiotic_names", "official"),
+                     translate_ab = "name",
+                     language = get_locale(),
+                     combine_SI = TRUE,
                      combine_IR = FALSE) {
 
-  if (!"data.frame" %in% class(data)) {
-    stop("`count_df` must be called on a data.frame")
-  }
-
-  if (data %>% select_if(is.rsi) %>% ncol() == 0) {
-    stop("No columns with class 'rsi' found. See ?as.rsi.")
-  }
-
-  if (as.character(translate_ab) == "TRUE") {
-    translate_ab <- "official"
-  }
-  options(get_antibiotic_names = translate_ab)
-
-  resS <- summarise_if(.tbl = data,
-                       .predicate = is.rsi,
-                       .funs = count_S) %>%
-    mutate(Interpretation = "S") %>%
-    select(Interpretation, everything())
-
-  if (combine_IR == FALSE) {
-    resI <- summarise_if(.tbl = data,
-                         .predicate = is.rsi,
-                         .funs = count_I) %>%
-      mutate(Interpretation = "I") %>%
-      select(Interpretation, everything())
-
-    resR <- summarise_if(.tbl = data,
-                         .predicate = is.rsi,
-                         .funs = count_R) %>%
-      mutate(Interpretation = "R") %>%
-      select(Interpretation, everything())
-
-    data.groups <- group_vars(data)
-
-    res <- bind_rows(resS, resI, resR) %>%
-      mutate(Interpretation = factor(Interpretation, levels = c("R", "I", "S"), ordered = TRUE)) %>%
-      tidyr::gather(Antibiotic, Value, -Interpretation, -data.groups)
-  } else {
-    resIR <- summarise_if(.tbl = data,
-                          .predicate = is.rsi,
-                          .funs = count_IR) %>%
-      mutate(Interpretation = "IR") %>%
-      select(Interpretation, everything())
-
-    data.groups <- group_vars(data)
-
-    res <- bind_rows(resS, resIR) %>%
-      mutate(Interpretation = factor(Interpretation, levels = c("IR", "S"), ordered = TRUE)) %>%
-      tidyr::gather(Antibiotic, Value, -Interpretation, -data.groups)
-  }
-
-  if (!translate_ab == FALSE) {
-    if (!tolower(translate_ab) %in% tolower(colnames(AMR::antibiotics))) {
-      stop("Parameter `translate_ab` does not occur in the `antibiotics` data set.", call. = FALSE)
-    }
-    res <- res %>% mutate(Antibiotic = abname(Antibiotic, from = "guess", to = translate_ab))
-  }
-
-  res
+  rsi_calc_df(type = "count",
+              data = data,
+              translate_ab = translate_ab,
+              language = language,
+              combine_SI = combine_SI,
+              combine_IR = combine_IR,
+              combine_SI_missing = missing(combine_SI))
 }
