@@ -16,23 +16,56 @@
 # This R package was created for academic research and was publicly    #
 # released in the hope that it will be useful, but it comes WITHOUT    #
 # ANY WARRANTY OR LIABILITY.                                           #
-# Visit our website for more info: https://msberends.gitab.io/AMR.     #
+# Visit our website for more info: https://msberends.gitlab.io/AMR.    #
 # ==================================================================== #
 
-#' Get language for AMR
+#' Translate strings from AMR package
 #'
-#' Determines the system language to be used for language-dependent output of AMR functions, like \code{\link{mo_gramstain}} and \code{\link{mo_type}}.
-#' @details The system language can be overwritten with \code{\link{getOption}("AMR_locale")}.
-#' @section Supported languages:
-#' Supported languages are \code{"en"} (English), \code{"de"} (German), \code{"nl"} (Dutch), \code{"es"} (Spanish), \code{"it"} (Italian), \code{"fr"} (French), and \code{"pt"} (Portuguese).
+#' For language-dependent output of AMR functions, like \code{\link{mo_fullname}} and \code{\link{mo_type}}.
+#' @details Strings will be translated to foreign languages if they are defined in a local translation file. Additions to this file can be suggested at our repository. The file can be found here: \url{https://gitlab.com/msberends/AMR/blob/master/data-raw/translations.tsv}.
+#'
+#' Please suggest your own translations \href{https://gitlab.com/msberends/AMR/issues/new?issue[title]=Translation\%20suggestion}{by creating a new issue on our repository}.
+#'
+#' This file will be read by all functions where a translated output can be desired, like all \code{\link{mo_property}} functions (\code{\link{mo_fullname}}, \code{\link{mo_type}}, etc.).
+#'
+#' The system language will be used at default, if supported, using \code{\link{get_locale}}. The system language can be overwritten with \code{\link{getOption}("AMR_locale")}.
 #' @inheritSection AMR Read more on our website!
+#' @rdname translate
+#' @name translate
 #' @export
+#' @examples
+#' # The 'language' parameter of below functions
+#' # will be set automatically to your system language
+#' # with get_locale()
+#'
+#' # English
+#' mo_fullname("CoNS", language = "en")
+#' #> "Coagulase-negative Staphylococcus (CoNS)"
+#'
+#' # German
+#' mo_fullname("CoNS", language = "de")
+#' #> "Koagulase-negative Staphylococcus (KNS)"
+#'
+#' # Dutch
+#' mo_fullname("CoNS", language = "nl")
+#' #> "Coagulase-negatieve Staphylococcus (CNS)"
+#'
+#' # Spanish
+#' mo_fullname("CoNS", language = "es")
+#' #> "Staphylococcus coagulasa negativo (SCN)"
+#'
+#' # Italian
+#' mo_fullname("CoNS", language = "it")
+#' #> "Staphylococcus negativo coagulasi (CoNS)"
+#'
+#' # Portuguese
+#' mo_fullname("CoNS", language = "pt")
+#' #> "Staphylococcus coagulase negativo (CoNS)"
 get_locale <- function() {
-  if (!is.null(getOption("AMR_locale"))) {
-    if (getOption("AMR_locale") %in% c("en", "de", "nl", "es", "it", "fr", "pt")) {
-      return(getOption("AMR_locale"))
-    }
+  if (getOption("AMR_locale", "en") != "en") {
+    return(getOption("AMR_locale"))
   }
+
   lang <- Sys.getlocale("LC_COLLATE")
   # grepl with case = FALSE is faster than like
   if (grepl("^(English|en_|EN_)", lang, ignore.case = FALSE)) {
