@@ -16,18 +16,24 @@
 # This R package was created for academic research and was publicly    #
 # released in the hope that it will be useful, but it comes WITHOUT    #
 # ANY WARRANTY OR LIABILITY.                                           #
-# Visit our website for more info: https://msberends.gitab.io/AMR.     #
+# Visit our website for more info: https://msberends.gitlab.io/AMR.    #
 # ==================================================================== #
 
 globalVariables(c(".",
                   "..property",
+                  "ab",
+                  "abbreviations",
+                  "mdr",
+                  "mono_count",
+                  "second",
+                  "xdr",
                   "antibiotic",
                   "Antibiotic",
                   "antibiotics",
                   "atc",
                   "authors",
                   "Becker",
-                  "certe",
+                  "CNS_CPS",
                   "cnt",
                   "col_id",
                   "count",
@@ -46,8 +52,8 @@ globalVariables(c(".",
                   "genus",
                   "gramstain",
                   "index",
-                  "Interpretation",
                   "input",
+                  "Interpretation",
                   "item",
                   "key_ab",
                   "key_ab_lag",
@@ -55,8 +61,10 @@ globalVariables(c(".",
                   "kingdom",
                   "labs",
                   "Lancefield",
+                  "lang",
                   "Last name",
                   "lbl",
+                  "lookup",
                   "median",
                   "mic",
                   "microorganisms",
@@ -69,6 +77,7 @@ globalVariables(c(".",
                   "mo",
                   "mo.old",
                   "more_than_episode_ago",
+                  "MPM",
                   "n",
                   "name",
                   "new",
@@ -81,6 +90,7 @@ globalVariables(c(".",
                   "Pasted",
                   "patient_id",
                   "phylum",
+                  "plural",
                   "prevalence",
                   "prevalent",
                   "property",
@@ -88,6 +98,11 @@ globalVariables(c(".",
                   "R",
                   "real_first_isolate",
                   "ref",
+                  "reference.rule",
+                  "reference.rule_group",
+                  "rsi",
+                  "rule_group",
+                  "rule_name",
                   "S",
                   "se_max",
                   "se_min",
@@ -97,11 +112,13 @@ globalVariables(c(".",
                   "species",
                   "species_id",
                   "subspecies",
+                  "synonyms",
                   "trade_name",
+                  "trans",
                   "transmute",
                   "tsn",
                   "tsn_new",
-                  "umcg",
+                  "txt",
                   "value",
                   "Value",
                   "x",
