@@ -1,7 +1,7 @@
 ## ----setup, include = FALSE, results = 'markup'--------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
-  comment = "#>",
+  comment = "#",
   fig.width = 7.5,
   fig.height = 4.5
 )
