@@ -1,7 +1,7 @@
 ## ----setup, include = FALSE, results = 'markup'--------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
-  comment = "#>"
+  comment = "#"
 )
 # set to original language (English)
 Sys.setlocale(locale = "C")
