@@ -16,7 +16,7 @@
 # This R package was created for academic research and was publicly    #
 # released in the hope that it will be useful, but it comes WITHOUT    #
 # ANY WARRANTY OR LIABILITY.                                           #
-# Visit our website for more info: https://msberends.gitab.io/AMR.     #
+# Visit our website for more info: https://msberends.gitlab.io/AMR.    #
 # ==================================================================== #
 
 context("first_isolate.R")
@@ -25,19 +25,19 @@ test_that("first isolates work", {
   # first isolates
   expect_equal(
     sum(
-      first_isolate(tbl = septic_patients,
+      first_isolate(x = septic_patients,
                     col_date = "date",
                     col_patient_id = "patient_id",
                     col_mo = "mo",
                     info = TRUE),
       na.rm = TRUE),
-    1274)
+    1317)
 
   # first *weighted* isolates
   expect_equal(
     suppressWarnings(
       sum(
-        first_isolate(tbl = septic_patients %>% mutate(keyab = key_antibiotics(.)),
+        first_isolate(x = septic_patients %>% mutate(keyab = key_antibiotics(.)),
                       # let syntax determine these automatically:
                       # col_date = "date",
                       # col_patient_id = "patient_id",
@@ -46,12 +46,12 @@ test_that("first isolates work", {
                       type = "keyantibiotics",
                       info = TRUE),
         na.rm = TRUE)),
-    1369)
+    1413)
   # should be same for tibbles
   expect_equal(
     suppressWarnings(
       sum(
-        first_isolate(tbl = septic_patients %>% dplyr::as_tibble() %>% mutate(keyab = key_antibiotics(.)),
+        first_isolate(x = septic_patients %>% dplyr::as_tibble() %>% mutate(keyab = key_antibiotics(.)),
                       # let syntax determine these automatically:
                       # col_date = "date",
                       # col_patient_id = "patient_id",
@@ -60,12 +60,12 @@ test_that("first isolates work", {
                       type = "keyantibiotics",
                       info = TRUE),
         na.rm = TRUE)),
-    1369)
+    1413)
   # when not ignoring I
   expect_equal(
     suppressWarnings(
       sum(
-        first_isolate(tbl = septic_patients %>% mutate(keyab = key_antibiotics(.)),
+        first_isolate(x = septic_patients %>% mutate(keyab = key_antibiotics(.)),
                       col_date = "date",
                       col_patient_id = "patient_id",
                       col_mo = "mo",
@@ -74,12 +74,12 @@ test_that("first isolates work", {
                       type = "keyantibiotics",
                       info = TRUE),
         na.rm = TRUE)),
-    1392)
+    1436)
   # when using points
   expect_equal(
     suppressWarnings(
       sum(
-        first_isolate(tbl = septic_patients %>% mutate(keyab = key_antibiotics(.)),
+        first_isolate(x = septic_patients %>% mutate(keyab = key_antibiotics(.)),
                       col_date = "date",
                       col_patient_id = "patient_id",
                       col_mo = "mo",
@@ -87,7 +87,7 @@ test_that("first isolates work", {
                       type = "points",
                       info = TRUE),
         na.rm = TRUE)),
-    1372)
+    1417)
 
   # first non-ICU isolates
   expect_equal(
@@ -100,13 +100,13 @@ test_that("first isolates work", {
                     info = TRUE,
                     icu_exclude = TRUE),
       na.rm = TRUE),
-    1129)
+    1163)
 
   # set 1500 random observations to be of specimen type 'Urine'
   random_rows <- sample(x = 1:2000, size = 1500, replace = FALSE)
   expect_lt(
     sum(
-      first_isolate(tbl = mutate(septic_patients,
+      first_isolate(x = mutate(septic_patients,
                                  specimen = if_else(row_number() %in% random_rows,
                                                     "Urine",
                                                     "Other")),
@@ -121,7 +121,7 @@ test_that("first isolates work", {
   # same, but now exclude ICU
   expect_lt(
     sum(
-      first_isolate(tbl = mutate(septic_patients,
+      first_isolate(x = mutate(septic_patients,
                                  specimen = if_else(row_number() %in% random_rows,
                                                     "Urine",
                                                     "Other")),
@@ -175,4 +175,17 @@ test_that("first isolates work", {
                                    col_mo = "mo",
                                    col_patient_id = "patient_id"))
 
+  # missing dates should be no problem
+  df <- septic_patients
+  df[1:100, "date"] <- NA
+  expect_equal(
+    sum(
+      first_isolate(x = df,
+                    col_date = "date",
+                    col_patient_id = "patient_id",
+                    col_mo = "mo",
+                    info = TRUE),
+      na.rm = TRUE),
+    1322)
+
 })
