@@ -16,7 +16,7 @@
 # This R package was created for academic research and was publicly    #
 # released in the hope that it will be useful, but it comes WITHOUT    #
 # ANY WARRANTY OR LIABILITY.                                           #
-# Visit our website for more info: https://msberends.gitab.io/AMR.     #
+# Visit our website for more info: https://msberends.gitlab.io/AMR.    #
 # ==================================================================== #
 
 context("mo_property.R")
@@ -31,6 +31,7 @@ test_that("mo_property works", {
   expect_equal(mo_species("E. coli"), "coli")
   expect_equal(mo_subspecies("E. coli"), "")
   expect_equal(mo_fullname("E. coli"), "Escherichia coli")
+  expect_equal(mo_name("E. coli"), "Escherichia coli")
   expect_equal(mo_type("E. coli", language = "en"), "Bacteria")
   expect_equal(mo_gramstain("E. coli", language = "en"), "Gram negative")
   expect_equal(class(mo_taxonomy("E. coli")), "list")
@@ -47,6 +48,8 @@ test_that("mo_property works", {
   expect_equal(mo_shortname("S. agalac"), "S. agalactiae")
   expect_equal(mo_shortname("S. agalac", Lancefield = TRUE), "GBS")
 
+  expect_true(mo_url("Escherichia coli") %like% "www.catalogueoflife.org")
+
   # test integrity
   MOs <- AMR::microorganisms
   expect_identical(MOs$fullname, mo_fullname(MOs$fullname, language = "en"))
